/* NetworkGraphLayoutAlgorithm.java

	Purpose:
		
	Description:
		
	History:
		Fri Nov 15 11:29:03 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.Optionable;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Link style options.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class NetworkGraphLink extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		color, dashStyle, length, width
	}

	/**
	 * Returns the color of the link between two nodes.
	 * <p>
	 * Default: rgba(100, 100, 100, 0.5)
	 */
	public String getColor() {
		return getAttr(Attrs.color, "rgba(100, 100, 100, 0.5)").asString();
	}

	/**
	 * Sets the color of the link between two nodes.
	 */
	public void setColor(String color) {
		setAttr(Attrs.color, color);
	}

	/**
	 * Returns a name for the dash style to use for links.
	 * <p>
	 * Default: null
	 */
	public String getDashStyle() {
		return getAttr(Attrs.dashStyle, null).asString();
	}

	/**
	 * Sets a name for the dash style to use for links.
	 */
	public void setDashStyle(String dashStyle) {
		setAttr(Attrs.dashStyle, dashStyle);
	}

	/**
	 * Returns the length (px) of the link between two nodes.
	 * <p>
	 * Default: null
	 */
	public Number getLength() {
		return getAttr(Attrs.length, null).asNumber();
	}

	/**
	 * Sets the length (px) of the link between two nodes.
	 */
	public void setLength(Number length) {
		setAttr(Attrs.length, length);
	}

	/**
	 * Returns the width (px) of the link between two nodes.
	 * <p>
	 * Default: 1
	 */
	public Number getWidth() {
		return getAttr(Attrs.width, 1).asNumber();
	}

	/**
	 * Sets the width (px) of the link between two nodes.
	 */
	public void setWidth(Number width) {
		setAttr(Attrs.width, width, 1);
	}
}
