/* WindBarbDataGrouping.java

	Purpose:
		
	Description:
		
	History:
		Fri Dec 06 11:32:26 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.Optionable;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;
import org.zkoss.json.JavaScriptValue;

/**
 * Data grouping options for the wind barbs.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class WindBarbDataGrouping extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		approximation, enabled, groupPixelWidth
	}

	/**
	 * Returns approximation function for the data grouping.
	 * The default returns an average of wind speed and a vector average direction weighted by wind speed.
	 * <p>
	 * Default: "windbarb"
	 */
	public Object getApproximation() {
		return getAttr(Attrs.approximation, "windbarb");
	}

	/**
	 * Sets approximation function for the data grouping.
	 */
	public void setApproximation(String approximation) {
		setAttr(Attrs.approximation, approximation);
	}

	/**
	 * Sets approximation function for the data grouping.
	 */
	public void setApproximation(JavaScriptValue approximation) {
		setAttr(Attrs.approximation, approximation);
	}

	/**
	 * Returns whether to enable data grouping.
	 * <p>
	 * Default: true
	 */
	public boolean isEnabled() {
		return getAttr(Attrs.enabled, true).asBoolean();
	}

	/**
	 * Sets whether to enable data grouping.
	 */
	public void setEnabled(boolean enabled) {
		setAttr(Attrs.enabled, enabled);
	}

	/**
	 * Returns the approximate data group width.
	 * <p>
	 * Default: 30
	 */
	public Number getGroupPixelWidth() {
		return getAttr(Attrs.groupPixelWidth, 30).asNumber();
	}

	/**
	 * Sets the approximate data group width.
	 */
	public void setGroupPixelWidth(Number groupPixelWidth) {
		setAttr(Attrs.groupPixelWidth, groupPixelWidth);
	}
}
